Package: chatAI4R
Type: Package
Title: Chat-Based Interactive Artificial Intelligence for R
Version: 0.2.10
Date: 2023-09-05
Authors@R: c(
    person (given = "Satoshi", family = "Kume",
    role = c("aut", "cre"), 
    email = "satoshi.kume.1984@gmail.com",
    comment = c(ORCID = "0000-0001-7481-2843"))
    )
Maintainer: Satoshi Kume <satoshi.kume.1984@gmail.com>
Description: The Large Language Model (LLM) represents a groundbreaking advancement 
    in data science and programming, and also allows us to extend the world of R. 
    A seamless interface for integrating the 'OpenAI' Web APIs into R is provided in this package. 
    This package leverages LLM-based AI techniques, enabling efficient knowledge discovery and data analysis 
    (see 'OpenAI' Web APIs details <https://openai.com/blog/openai-api>).
    The previous functions such as seamless translation and image generation have been moved 
    to other packages 'deepRstudio' and 'stableDiffusion4R'.
Depends: R (>= 4.2.0)
Imports: httr, jsonlite, assertthat, clipr, crayon, rstudioapi, future,
        igraph, deepRstudio, pdftools, xml2, rvest
Suggests: testthat, knitr
License: Artistic-2.0
URL: https://kumes.github.io/chatAI4R/,
        https://github.com/kumeS/chatAI4R
BugReports: https://github.com/kumeS/chatAI4R/issues
RoxygenNote: 7.2.3
Encoding: UTF-8
Author: Satoshi Kume [aut, cre] (<https://orcid.org/0000-0001-7481-2843>)
Built: R 4.4.0; ; 2024-05-24 04:46:35 UTC; unix
