# Generated by roxygen2: do not edit by hand

export(OptimizeRcode)
export(RcodeImprovements)
export(TextSummary)
export(TextSummaryAsBullet)
export(addCommentCode)
export(addRoxygenDescription)
export(autocreateFunction4R)
export(chat4R)
export(chat4R_history)
export(chatAI4pdf)
export(checkErrorDet)
export(checkErrorDet_JP)
export(completions4R)
export(conversation4R)
export(convertBullet2Sentence)
export(convertRscript2Function)
export(convertScientificLiterature)
export(createImagePrompt_v1)
export(createImagePrompt_v2)
export(createRcode)
export(createRfunction)
export(createSpecifications4R)
export(designPackage)
export(discussion_flow_v1)
export(enrichTextContent)
export(extractKeywords)
export(ngsub)
export(proofreadEnglishText)
export(proofreadText)
export(removeQuotations)
export(revisedText)
export(searchFunction)
export(slow_print_v2)
export(speakInJA)
export(speakInJA_v2)
export(summaryWebScrapingText)
export(supportIdeaGeneration)
export(textEmbedding)
importFrom(assertthat,assert_that)
importFrom(assertthat,is.count)
importFrom(assertthat,is.flag)
importFrom(assertthat,is.number)
importFrom(assertthat,is.string)
importFrom(assertthat,noNA)
importFrom(clipr,read_clip)
importFrom(clipr,write_clip)
importFrom(crayon,red)
importFrom(deepRstudio,deepel)
importFrom(deepRstudio,is_mac)
importFrom(future,future)
importFrom(future,multisession)
importFrom(future,plan)
importFrom(future,resolved)
importFrom(httr,POST)
importFrom(httr,add_headers)
importFrom(httr,content)
importFrom(igraph,add_edges)
importFrom(igraph,add_vertices)
importFrom(igraph,graph)
importFrom(igraph,layout_nicely)
importFrom(igraph,layout_with_fr)
importFrom(jsonlite,toJSON)
importFrom(pdftools,pdf_text)
importFrom(rstudioapi,getActiveDocumentContext)
importFrom(rstudioapi,insertText)
importFrom(rstudioapi,isAvailable)
importFrom(rvest,html_attr)
importFrom(rvest,html_nodes)
importFrom(rvest,html_text)
importFrom(rvest,read_html)
importFrom(stats,runif)
importFrom(utils,URLencode)
importFrom(utils,askYesNo)
importFrom(utils,menu)
importFrom(utils,setTxtProgressBar)
importFrom(utils,txtProgressBar)
importFrom(xml2,read_html)
